Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(85)

Unified Diff: ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm

Issue 2672823003: Rename ReadingListViewController to ReadingListCollectionViewController (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm
diff --git a/ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm b/ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm
index c8c1954f70f9db8714fca0fcc4a2a9e6d97673b9..c7a1631b19eb7c44c7cf34991c631b0d67ce91cc 100644
--- a/ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm
+++ b/ios/chrome/browser/ui/reading_list/reading_list_view_controller_container_unittest.mm
@@ -13,8 +13,8 @@
#include "components/reading_list/ios/reading_list_entry.h"
#include "components/reading_list/ios/reading_list_model_impl.h"
#import "ios/chrome/browser/ui/collection_view/collection_view_model.h"
+#import "ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h"
#import "ios/chrome/browser/ui/reading_list/reading_list_collection_view_item.h"
-#import "ios/chrome/browser/ui/reading_list/reading_list_view_controller.h"
#import "ios/chrome/browser/ui/url_loader.h"
#include "ios/web/public/referrer.h"
#import "ios/web/public/test/web_test_with_web_state.h"
@@ -133,8 +133,9 @@ class ReadingListViewControllerContainerTest : public web::WebTestWithWebState {
ReadingListModel* GetReadingListModel() { return reading_list_model_.get(); }
UrlLoaderStub* GetLoaderStub() { return loader_mock_; }
- ReadingListViewController* GetAReadingListViewController() {
- return [[[ReadingListViewController alloc]
+ ReadingListCollectionViewController*
+ GetAReadingListCollectionViewController() {
+ return [[[ReadingListCollectionViewController alloc]
initWithModel:reading_list_model_.get()
largeIconService:large_icon_service_.get()
readingListDownloadService:nil
@@ -149,7 +150,7 @@ class ReadingListViewControllerContainerTest : public web::WebTestWithWebState {
std::unique_ptr<MockFaviconService> mock_favicon_service_;
};
// Tests that the implementation of ReadingListViewController
// openItemAtIndexPath opens the entry.
TEST_F(ReadingListViewControllerContainerTest, OpenItem) {
// Setup.
@@ -168,8 +169,9 @@ TEST_F(ReadingListViewControllerContainerTest, OpenItem) {
distillationState:ReadingListEntry::PROCESSED]);
// Action.
- [GetContainer() readingListViewController:GetAReadingListViewController()
- openItem:item];
+ [GetContainer() readingListCollectionViewController:
+ GetAReadingListCollectionViewController()
+ openItem:item];
// Tests.
UrlLoaderStub* loader = GetLoaderStub();
@@ -149,7 +150,7 @@ class ReadingListViewControllerContainerTest : public web::WebTestWithWebState {
std::unique_ptr<MockFaviconService> mock_favicon_service_;
};
-// Tests that the implementation of ReadingListViewController
+// Tests that the implementation of ReadingListCollectionViewController
// openItemAtIndexPath opens the entry.
TEST_F(ReadingListViewControllerContainerTest, OpenItem) {

Powered by Google App Engine
This is Rietveld 408576698